@@ -32,6 +32,7 @@ pub enum ErrorContext {
   InvalidGlobalUtils,
   GlobPattern,
   UnrecognizableLanguage(String),
+  LangInjection,
   // Run
   ParsePattern,
   LanguageNotSpecified,
@@ -71,7 +72,7 @@ impl ErrorContext {
       ReadConfiguration | ReadRule(_) | WalkRuleDir(_) | WriteFile(_) => 5,
       StdInIsNotInteractive => 6,
       ParseTest(_) | ParseRule(_) | ParseConfiguration | GlobPattern | ParsePattern
-      | InvalidGlobalUtils => 8,
+      | InvalidGlobalUtils | LangInjection => 8,
       CannotInferShell => 10,
       ProjectAlreadyExist | FileAlreadyExist(_) => 17,
       InsufficientCLIArgument(_) => 22,
@@ -147,6 +148,11 @@ impl ErrorMessage {
         "The pattern in files/ignore is not a valid glob. Please refer to doc and fix the error.",
         CONFIG_GUIDE,
       ),
+      LangInjection => Self::new(
+        "Cannot parse languageInjections in config",
+        "The rule in languageInjections is not valid. Please refer to doc and fix the error.",
+        CONFIG_GUIDE,
+      ),
       InvalidGlobalUtils => Self::new(
         "Error occurs when parsing global utility rules",
         "Please check the YAML rules inside the rule directory",
