@@ -1,7 +1,7 @@
 from __future__ import annotations
 
-from typing import List, TypedDict,  Literal, Dict, Union, Mapping
-from .ast_grep_py import SgNode, SgRoot, Pos, Range, Edit
+from typing import List, TypedDict,  Literal, Dict, Union, Mapping, Optional
+from .ast_grep_py import SgNode, SgRoot, Pos, Range, Edit, register_dynamic_language
 
 Strictness = Union[Literal["cst"], Literal["smart"], Literal["ast"], Literal["relaxed"], Literal["signature"]]
 
@@ -55,6 +55,12 @@ class Config(TypedDict, total=False):
     utils: Dict[str, Rule]
     transform: Dict[str, Mapping]
 
+class CustomLang(TypedDict, total=False):
+  library_path: str
+  language_symbol: Optional[str]
+  meta_var_char: Optional[str]
+  expando_char: Optional[str]
+
 __all__ = [
     "Rule",
     "Config",
@@ -66,4 +72,5 @@ __all__ = [
     "Pos",
     "Range",
     "Edit",
+    "register_dynamic_language",
 ]
\ No newline at end of file
